pub struct GoogleFirebaseAppcheckV1betaAppCheckToken {
pub attestation_token: Option<String>,
pub token: Option<String>,
pub ttl: Option<Duration>,
}Expand description
Encapsulates an App Check token, which are used to access backend services protected by App Check.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- exchange app attest assertion oauth clients (response)
- exchange debug token oauth clients (response)
- apps exchange app attest assertion projects (response)
- apps exchange custom token projects (response)
- apps exchange debug token projects (response)
- apps exchange device check token projects (response)
- apps exchange play integrity token projects (response)
- apps exchange recaptcha enterprise token projects (response)
- apps exchange recaptcha token projects (response)
- apps exchange recaptcha v3 token projects (response)
- apps exchange safety net token projects (response)
Fields
attestation_token: Option<String>The App Check token. App Check tokens are signed JWTs containing claims that identify the attested app and GCP project. This token is used to access Google services protected by App Check. These tokens can also be verified by your own custom backends using the Firebase Admin SDK or third-party libraries.
token: Option<String>The App Check token. App Check tokens are signed JWTs containing claims that identify the attested app and GCP project. This token is used to access Google services protected by App Check. These tokens can also be verified by your own custom backends using the Firebase Admin SDK or third-party libraries.
ttl: Option<Duration>The duration from the time this token is minted until its expiration. This field is intended to ease client-side token management, since the client may have clock skew, but is still able to accurately measure a duration.