pub struct GoogleFirebaseAppcheckV1betaSafetyNetConfig {
pub name: Option<String>,
pub token_ttl: Option<Duration>,
}Expand description
An app’s SafetyNet configuration object. This configuration controls certain properties of the AppCheckToken returned by ExchangeSafetyNetToken, such as its ttl. Note that your registered SHA-256 certificate fingerprints are used to validate tokens issued by SafetyNet; please register them via the Firebase Console or programmatically via the Firebase Management Service.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- apps safety net config get projects (response)
- apps safety net config patch projects (request|response)
Fields
name: Option<String>Required. The relative resource name of the SafetyNet configuration object, in the format: projects/{project_number}/apps/{app_id}/safetyNetConfig
token_ttl: Option<Duration>Specifies the duration for which App Check tokens exchanged from SafetyNet tokens will be valid. If unset, a default value of 1 hour is assumed. Must be between 30 minutes and 7 days, inclusive.